You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tamaya.apache.org by an...@apache.org on 2014/12/02 11:06:34 UTC

[4/4] incubator-tamaya git commit: TAMAYA-16: Changed aggregationPolicy to interface.

TAMAYA-16: Changed aggregationPolicy to interface.


Project: http://git-wip-us.apache.org/repos/asf/incubator-tamaya/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-tamaya/commit/d18afb10
Tree: http://git-wip-us.apache.org/repos/asf/incubator-tamaya/tree/d18afb10
Diff: http://git-wip-us.apache.org/repos/asf/incubator-tamaya/diff/d18afb10

Branch: refs/heads/master
Commit: d18afb1055fe2323c42029dac1cac0005bea3aa3
Parents: a55d1c9
Author: anatole <an...@apache.org>
Authored: Tue Dec 2 11:06:18 2014 +0100
Committer: anatole <an...@apache.org>
Committed: Tue Dec 2 11:06:19 2014 +0100

----------------------------------------------------------------------
 api/pom.xml                                     |   2 +-
 .../org/apache/tamaya/AggregationPolicy.java    |  36 +++++-
 .../java/org/apache/tamaya/ConfigChangeSet.java |  14 +--
 .../apache/tamaya/ConfigChangeSetBuilder.java   |  38 +++---
 .../java/org/apache/tamaya/ConfigOperator.java  |   4 +-
 .../java/org/apache/tamaya/Configuration.java   |  26 ++---
 .../org/apache/tamaya/ConfigurationManager.java |   4 +-
 .../java/org/apache/tamaya/Environment.java     |  28 ++---
 .../org/apache/tamaya/EnvironmentManager.java   |  18 +--
 .../main/java/org/apache/tamaya/MetaInfo.java   |  10 +-
 .../java/org/apache/tamaya/MetaInfoBuilder.java |   8 +-
 .../java/org/apache/tamaya/PropertyAdapter.java |   2 +-
 .../org/apache/tamaya/PropertyProvider.java     |  10 +-
 .../org/apache/tamaya/PropertyProviders.java    |  65 ++++++-----
 .../tamaya/annot/ConfigChangeListener.java      |   2 +-
 .../tamaya/annot/ConfiguredProperties.java      |   8 +-
 .../apache/tamaya/annot/ConfiguredProperty.java |   8 +-
 .../org/apache/tamaya/annot/DefaultAreas.java   |   2 +-
 .../org/apache/tamaya/annot/LoadPolicy.java     |   2 +-
 .../org/apache/tamaya/annot/WithConfig.java     |   4 +-
 .../apache/tamaya/annot/WithConfigOperator.java |   2 +-
 .../spi/ConfigurationManagerSingletonSpi.java   |   4 +-
 .../tamaya/spi/DefaultServiceProvider.java      |   8 +-
 .../spi/EnvironmentManagerSingletonSpi.java     |  20 ++--
 .../spi/PropertyProvidersSingletonSpi.java      |  20 ++--
 .../org/apache/tamaya/spi/ServiceProvider.java  |   6 +-
 .../TestConfigServiceSingletonSpi.java          |  16 +--
 .../TestPropertyAdaptersSingletonSpi.java       |   2 +-
 core/pom.xml                                    |   2 +-
 .../core/config/AbstractConfiguration.java      |   4 +-
 .../core/config/ConfigurationBuilder.java       |   2 +-
 .../core/config/ConfigurationFormats.java       |   6 +-
 .../config/EnvPropertiesConfigProvider.java     |   2 +-
 .../core/config/FreezedConfiguration.java       |   2 +-
 .../config/SystemPropertiesConfigProvider.java  |   2 +-
 .../core/env/ConfiguredSystemProperties.java    |   4 +-
 .../tamaya/core/env/EnvironmentSelector.java    |   2 +-
 .../internal/AggregatedPropertyProvider.java    |  39 ++-----
 .../internal/ContextualPropertyProvider.java    |   6 +-
 .../core/internal/DefaultConfigProvider.java    |   2 +-
 ...DefaultConfigurationManagerSingletonSpi.java |   4 +-
 .../internal/DefaultExpressionEvaluator.java    |   4 +-
 .../DefaultPropertyProvidersSingletonSpi.java   |  20 ++--
 .../tamaya/core/internal/DefaultStage.java      |   2 +-
 .../internal/DelegatingPropertyProvider.java    |   4 +-
 .../core/internal/FreezedPropertyProvider.java  |   2 +-
 .../internal/PathBasedPropertyProvider.java     |  20 +---
 .../internal/ReplacingPropertyProvider.java     |   2 +-
 .../tamaya/core/internal/StageBuilder.java      |   2 +-
 .../core/internal/UriBasedPropertyProvider.java |  21 +---
 .../tamaya/core/internal/el/ELResolver.java     |   4 +-
 .../core/internal/inject/ConfiguredField.java   |  12 +-
 .../inject/ConfiguredInstancesManager.java      |   2 +-
 .../core/internal/inject/ConfiguredMethod.java  |  10 +-
 .../logging/AbstractDelegatingLogger.java       |   2 +-
 .../core/internal/logging/Log4j2Logger.java     |   2 +-
 .../core/internal/logging/Log4jLogger.java      |   4 +-
 .../core/internal/logging/Slf4jLogger.java      |   2 +-
 .../io/AbstractFileResolvingResource.java       |   6 +-
 .../internal/resources/io/AbstractResource.java |   6 +-
 .../internal/resources/io/AntPathMatcher.java   |  28 ++---
 .../resources/io/ClassPathResource.java         |   8 +-
 .../core/internal/resources/io/ClassUtils.java  | 116 +++++++++----------
 .../resources/io/DefaultResourceLoader.java     |   8 +-
 .../resources/io/FileSystemResource.java        |  14 +--
 .../resources/io/InputStreamResource.java       |   4 +-
 .../io/PathMatchingResourcePatternResolver.java |  64 +++++-----
 .../internal/resources/io/ReflectionUtils.java  |  20 ++--
 .../core/internal/resources/io/Resource.java    |  12 +-
 .../internal/resources/io/ResourceUtils.java    |   6 +-
 .../core/internal/resources/io/StringUtils.java | 104 ++++++++---------
 .../core/internal/resources/io/UrlResource.java |   8 +-
 .../core/internal/resources/io/VfsResource.java |   2 +-
 .../core/internal/resources/io/VfsUtils.java    |   2 +-
 .../internal/resources/io/WritableResource.java |   4 +-
 .../properties/AbstractPropertyProvider.java    |   2 +-
 .../MapBasedPropertyProviderBuilder.java        |   2 +-
 .../properties/PropertyProviderManager.java     |   8 +-
 .../apache/tamaya/core/properties/Store.java    |   2 +-
 .../tamaya/core/spi/ConfigurationFormat.java    |   2 +-
 .../spi/ConfigurationFormatsSingletonSpi.java   |   4 +-
 .../core/spi/ConfigurationProviderSpi.java      |   6 +-
 .../tamaya/core/spi/EnvironmentProvider.java    |   6 +-
 .../tamaya/core/spi/ExpressionResolver.java     |   4 +-
 .../apache/tamaya/core/spi/ResourceLoader.java  |  12 +-
 .../resources/META-INF/java-config-1.0.0.xsd    |   2 +-
 .../src/main/resources/META-INF/java-config.xml |   2 +-
 .../resources/META-INF/meta-model.properties    |   2 +-
 ....tamaya.core.internal.resources.PathResolver |   2 +-
 ...g.apache.tamaya.core.spi.ConfigurationFormat |   2 +-
 ...ya.core.spi.ConfigurationFormatsSingletonSpi |   2 +-
 ...che.tamaya.core.spi.ConfigurationProviderSpi |   2 +-
 ...g.apache.tamaya.core.spi.EnvironmentProvider |   2 +-
 ...rg.apache.tamaya.core.spi.ExpressionResolver |   2 +-
 .../org.apache.tamaya.core.spi.ResourceLoader   |   2 +-
 ....tamaya.spi.ConfigurationManagerSingletonSpi |   2 +-
 ...he.tamaya.spi.EnvironmentManagerSingletonSpi |   2 +-
 ...ache.tamaya.spi.PropertyAdaptersSingletonSpi |   2 +-
 ...che.tamaya.spi.PropertyProvidersSingletonSpi |   2 +-
 .../org.apache.tamaya.spi.StagesSingletonSpi    |   2 +-
 core/src/main/resources/log4j2.xml              |   2 +-
 ...tionManagerSingletonSpiSingletonSpiTest.java |   6 +-
 .../java/org/apache/tamaya/JavaOneDemo.java     |   2 +-
 .../core/config/EnvironmentManagerTest.java     |   2 +-
 .../tamaya/core/config/MutableConfigTest.java   |   2 +-
 .../env/ConfiguredSystemPropertiesTest.java     |   3 +-
 .../tamaya/core/env/EnvironmentManagerTest.java |  14 +--
 .../tamaya/internal/TestConfigProvider.java     |  14 +--
 .../java/org/apache/tamaya/package-info.java    |   4 +
 .../samples/annotations/ConfiguredTest.java     |   2 +-
 .../simple/SimplePropertiesAndCLISample.java    |   2 +-
 .../UC1ReadPropertiesTest.java                  |   8 +-
 .../UC2CombinePropertiesTest.java               |  74 ++++++++++++
 core/src/test/resources/META-INF/beans.xml      |   2 +-
 .../test/resources/META-INF/config.properties   |   2 +-
 .../META-INF/config/example.properties          |   2 +-
 .../test/resources/META-INF/config/example.xml  |   2 +-
 .../META-INF/env/application.properties         |   2 +-
 .../resources/META-INF/env/system.properties    |   2 +-
 .../resources/META-INF/meta-model.properties    |   2 +-
 ...che.tamaya.core.spi.ConfigurationProviderSpi |   2 +-
 ...tamaya.core.spi.PropertyAdaptersSingletonSpi |  15 ---
 core/src/test/resources/cfg/test.xml            |   2 +-
 core/src/test/resources/test.properties         |   2 +-
 .../UC1ReadProperties/UC1ReadPropertiesTest.xml |   2 +-
 .../ucs/UC2CombineProperties/props1.properties  |   6 +
 .../ucs/UC2CombineProperties/props2.properties  |   6 +
 modules/cdi/pom.xml                             |   2 +-
 .../cdi/src/main/resources/META-INF/beans.xml   |   2 +-
 .../javax.enterprise.inject.spi.Extension       |   2 +-
 .../tamaya/ext/cdi/TestConfigProvider.java      |  14 +--
 .../cdi/src/test/resources/META-INF/beans.xml   |   2 +-
 modules/managed/pom.xml                         |   2 +-
 .../tamaya/management/ManagedConfigMBean.java   |  16 +--
 .../tamaya/management/ManagedEnvironment.java   |   2 +-
 .../management/ManagedEnvironmentMBean.java     |   2 +-
 .../src/main/resources/META-INF/beans.xml       |   2 +-
 .../src/test/resources/META-INF/beans.xml       |   2 +-
 modules/pom.xml                                 |   2 +-
 139 files changed, 684 insertions(+), 601 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/pom.xml
----------------------------------------------------------------------
diff --git a/api/pom.xml b/api/pom.xml
index 5ecc567..78bd2b1 100644
--- a/api/pom.xml
+++ b/api/pom.xml
@@ -5,7 +5,7 @@ distributed with this work for additional information
 regarding copyright ownership.  The ASF licenses this file
 to you under the Apache License, Version 2.0 (the
 "License"); you may not use this file except in compliance
-with the License.  You may obtain a copy of the License at
+with the License.  You may obtain a copy current the License at
 
    http://www.apache.org/licenses/LICENSE-2.0
 

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/AggregationPolicy.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/AggregationPolicy.java b/api/src/main/java/org/apache/tamaya/AggregationPolicy.java
index 1b02a6c..1eb1a4a 100644
--- a/api/src/main/java/org/apache/tamaya/AggregationPolicy.java
+++ b/api/src/main/java/org/apache/tamaya/AggregationPolicy.java
@@ -21,18 +21,46 @@ package org.apache.tamaya;
 /**
  * Policy that defines how the different aggregates should be combined.
  */
-public enum AggregationPolicy{
+public interface AggregationPolicy {
+
+    /**
+     * Method which decides how keys/values are aggregated.
+     * @param key the key current the entry
+     * @param value1 the current value, or null.
+     * @param value2 the new value, never null.
+     * @return the target value to be used in the resulting property set, or null, to remove the property.
+     */
+    public String aggregate(String key, String value1, String value2);
+
     /** Ignore overrides, only extend (additive). */
-    IGNORE,
+    public static AggregationPolicy IGNORE_DUPLICATES() {
+        return (k, v1, v2) -> v1;
+    }
+
+    /** Combine multiple values into a comma separated list. */
+    public static AggregationPolicy COMBINE() {
+        return (k, v1, v2) -> v1 != null && v2 != null ? v1 + ',' + v2: v2;
+    }
+
     /**
      * Interpret later keys as override (additive and override), replacing
      * the key loaded earlier/fromMap previous contained
      * {@link org.apache.tamaya.PropertyProvider}.
      */
-    OVERRIDE,
+    public static AggregationPolicy OVERRIDE() {
+        return (k, v1, v2) -> v2;
+    }
+
     /**
      * Throw an exception, when keys are not disjunctive (strictly
      * additive).
      */
-    EXCEPTION
+    public static AggregationPolicy EXCEPTION() {
+        return (String key, String value, String newValue) -> {
+            if(value!=null && newValue!=null && !value.equals(newValue)){
+                throw new ConfigException("Conflicting values encountered key="+key+", value="+value+", newValue="+newValue);
+            }
+            return newValue;
+        };
+    }
 }

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/ConfigChangeSet.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/ConfigChangeSet.java b/api/src/main/java/org/apache/tamaya/ConfigChangeSet.java
index 76a7cea..0a00036 100644
--- a/api/src/main/java/org/apache/tamaya/ConfigChangeSet.java
+++ b/api/src/main/java/org/apache/tamaya/ConfigChangeSet.java
@@ -22,7 +22,7 @@ import java.beans.PropertyChangeEvent;
 import java.util.*;
 
 /**
- * Event that contains a set of changes that were applied or could be applied.
+ * Event that contains a set current changes that were applied or could be applied.
  * This class is immutable and thread-safe. To create instances use
  * {@link ConfigChangeSetBuilder}.
  *
@@ -82,24 +82,24 @@ public final class ConfigChangeSet {
     }
 
     /**
-     * Access the number of removed entries.
-     * @return the number of removed entries.
+     * Access the number current removed entries.
+     * @return the number current removed entries.
      */
     public int getRemovedSize() {
         return (int) this.changes.values().stream().filter((e) -> e.getNewValue() == null).count();
     }
 
     /**
-     * Access the number of added entries.
-     * @return the number of added entries.
+     * Access the number current added entries.
+     * @return the number current added entries.
      */
     public int getAddedSize() {
         return (int) this.changes.values().stream().filter((e) -> e.getOldValue() == null).count();
     }
 
     /**
-     * Access the number of updated entries.
-     * @return the number of updated entries.
+     * Access the number current updated entries.
+     * @return the number current updated entries.
      */
     public int getUpdatedSize() {
         return (int) this.changes.values().stream().filter((e) -> e.getOldValue()!=null && e.getNewValue()!=null).count();

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/ConfigChangeSetBuilder.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/ConfigChangeSetBuilder.java b/api/src/main/java/org/apache/tamaya/ConfigChangeSetBuilder.java
index 8f21228..be3cba2 100644
--- a/api/src/main/java/org/apache/tamaya/ConfigChangeSetBuilder.java
+++ b/api/src/main/java/org/apache/tamaya/ConfigChangeSetBuilder.java
@@ -23,9 +23,9 @@ import java.time.Instant;
 import java.util.*;
 
 /**
- * Models a set of changes to be applied to a configuration/property provider.  Such a set can be applied
+ * Models a set current changes to be applied to a configuration/property provider.  Such a set can be applied
  * to any {@link PropertyProvider} instance. If the provider is mutable it may check the
- * version given and apply the changes to the provider/configuration, including triggering of regarding
+ * version given and apply the changes to the provider/configuration, including triggering current regarding
  * change events.
  *
  * Created by Anatole on 06.09.2014.
@@ -50,7 +50,7 @@ public final class ConfigChangeSetBuilder {
     }
 
     /**
-     * Creates a new instance of this builder.
+     * Creates a new instance current this builder.
      * @param source the underlying property provider/configuration, not null.
      * @return the builder for chaining.
      */
@@ -59,7 +59,7 @@ public final class ConfigChangeSetBuilder {
     }
 
     /**
-     * Creates a new instance of this builder.
+     * Creates a new instance current this builder.
      * @param source the underlying property provider/configuration, not null.
      * @param baseVersion the base version to be used.
      * @return the builder for chaining.
@@ -69,7 +69,7 @@ public final class ConfigChangeSetBuilder {
     }
 
     /**
-     * Creates a new instance of this builder.
+     * Creates a new instance current this builder.
      * @param configuration the base configuration, not null.
      * @return the builder for chaining.
      */
@@ -101,7 +101,7 @@ public final class ConfigChangeSetBuilder {
 
     /**
      * Get the current values, also considering any changes recorded within this change set.
-     * @param key the key of the entry, not null.
+     * @param key the key current the entry, not null.
      * @return the value, or null.
      */
     public String get(String key) {
@@ -114,7 +114,7 @@ public final class ConfigChangeSetBuilder {
 
     /**
      * Marks the given key(s) fromMap the configuration/properties to be removed.
-     * @param key the key of the entry, not null.
+     * @param key the key current the entry, not null.
      * @param otherKeys additional keys to be removed (convenience), not null.
      * @return the builder for chaining.
      */
@@ -136,7 +136,7 @@ public final class ConfigChangeSetBuilder {
 
     /**
      * Applies the given value.
-     * @param key the key of the entry, not null.
+     * @param key the key current the entry, not null.
      * @param value the value to be applied, not null.
      * @return the builder for chaining.
      */
@@ -147,7 +147,7 @@ public final class ConfigChangeSetBuilder {
 
     /**
      * Applies the given value.
-     * @param key the key of the entry, not null.
+     * @param key the key current the entry, not null.
      * @param value the value to be applied, not null.
      * @return the builder for chaining.
      */
@@ -158,7 +158,7 @@ public final class ConfigChangeSetBuilder {
 
     /**
      * Applies the given value.
-     * @param key the key of the entry, not null.
+     * @param key the key current the entry, not null.
      * @param value the value to be applied, not null.
      * @return the builder for chaining.
      */
@@ -169,7 +169,7 @@ public final class ConfigChangeSetBuilder {
 
     /**
      * Applies the given value.
-     * @param key the key of the entry, not null.
+     * @param key the key current the entry, not null.
      * @param value the value to be applied, not null.
      * @return the builder for chaining.
      */
@@ -180,7 +180,7 @@ public final class ConfigChangeSetBuilder {
 
     /**
      * Applies the given value.
-     * @param key the key of the entry, not null.
+     * @param key the key current the entry, not null.
      * @param value the value to be applied, not null.
      * @return the builder for chaining.
      */
@@ -191,7 +191,7 @@ public final class ConfigChangeSetBuilder {
 
     /**
      * Applies the given value.
-     * @param key the key of the entry, not null.
+     * @param key the key current the entry, not null.
      * @param value the value to be applied, not null.
      * @return the builder for chaining.
      */
@@ -202,7 +202,7 @@ public final class ConfigChangeSetBuilder {
 
     /**
      * Applies the given value.
-     * @param key the key of the entry, not null.
+     * @param key the key current the entry, not null.
      * @param value the value to be applied, not null.
      * @return the builder for chaining.
      */
@@ -213,7 +213,7 @@ public final class ConfigChangeSetBuilder {
 
     /**
      * Applies the given value.
-     * @param key the key of the entry, not null.
+     * @param key the key current the entry, not null.
      * @param value the value to be applied, not null.
      * @return the builder for chaining.
      */
@@ -224,7 +224,7 @@ public final class ConfigChangeSetBuilder {
 
     /**
      * Applies the given value.
-     * @param key the key of the entry, not null.
+     * @param key the key current the entry, not null.
      * @param value the value to be applied, not null.
      * @return the builder for chaining.
      */
@@ -235,7 +235,7 @@ public final class ConfigChangeSetBuilder {
 
     /**
      * Applies the given value.
-     * @param key the key of the entry, not null.
+     * @param key the key current the entry, not null.
      * @param value the value to be applied, not null.
      * @return the builder for chaining.
      */
@@ -291,11 +291,11 @@ public final class ConfigChangeSetBuilder {
     }
 
     /**
-     * Compares the two property providers/configurations and creates a collection of all changes
+     * Compares the two property providers/configurations and creates a collection current all changes
      * that must be appied to render {@code map1} into {@code map2}.
      * @param map1 the source map, not null.
      * @param map2 the target map, not null.
-     * @return a collection of change events, never null.
+     * @return a collection current change events, never null.
      */
     public static Collection<PropertyChangeEvent> compare(PropertyProvider map1, PropertyProvider map2) {
         List<PropertyChangeEvent> changes = new ArrayList<>();

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/ConfigOperator.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/ConfigOperator.java b/api/src/main/java/org/apache/tamaya/ConfigOperator.java
index b76fa31..edbc9dc 100644
--- a/api/src/main/java/org/apache/tamaya/ConfigOperator.java
+++ b/api/src/main/java/org/apache/tamaya/ConfigOperator.java
@@ -21,14 +21,14 @@ package org.apache.tamaya;
 
 /**
  * Interface for an filter/operator that converts a configured String into another String. One typical
- * use case would the the decryption of an encrypted configuration value.
+ * use case would the the decryption current an encrypted configuration value.
  */
 @FunctionalInterface
 public interface ConfigOperator{
 
     /**
      * Method that creates a Configuration fromMap another Configuration. This can be used for implementing
-     * views, security constraints or for overriding/inheriting of configuration.
+     * views, security constraints or for overriding/inheriting current configuration.
      * @param config The target configuration to be operated, never nnull.
      * @return the operated configuration, never null.
      */

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/Configuration.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/ConfigurationManager.java b/api/src/main/java/org/apache/tamaya/ConfigurationManager.java
index 62cd984..d714f71 100644
--- a/api/src/main/java/org/apache/tamaya/ConfigurationManager.java
+++ b/api/src/main/java/org/apache/tamaya/ConfigurationManager.java
@@ -145,7 +145,7 @@ final class ConfigurationManager{
     }
 
     /**
-     * Adds a (global) {@link java.beans.PropertyChangeListener} instance that listens to all kind of config changes.
+     * Adds a (global) {@link java.beans.PropertyChangeListener} instance that listens to all kind current config changes.
      * @param listener the {@link java.beans.PropertyChangeListener} instance to be added, not null.
      */
     public static void addConfigChangeListener(PropertyChangeListener listener){
@@ -153,7 +153,7 @@ final class ConfigurationManager{
     }
 
     /**
-     * Removes a (global) {@link java.beans.PropertyChangeListener} instance that listens to all kind of config changes,
+     * Removes a (global) {@link java.beans.PropertyChangeListener} instance that listens to all kind current config changes,
      * if one is currently registered.
      * @param listener the {@link java.beans.PropertyChangeListener} instance to be removed, not null.
      */

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/Environment.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/EnvironmentManager.java b/api/src/main/java/org/apache/tamaya/EnvironmentManager.java
index 7de86a6..a6ae5cd 100644
--- a/api/src/main/java/org/apache/tamaya/EnvironmentManager.java
+++ b/api/src/main/java/org/apache/tamaya/EnvironmentManager.java
@@ -68,8 +68,8 @@ final class EnvironmentManager{
     }
 
     /**
-     * Evaluate the overall chain of possible environments.
-     * @return the hierarchy chain of possible Environments.
+     * Evaluate the overall chain current possible environments.
+     * @return the hierarchy chain current possible Environments.
      */
     public static List<String> getEnvironmentTypeOrder(){
         return Optional.ofNullable(environmentManagerSingletonSpi).orElseThrow(
@@ -78,8 +78,8 @@ final class EnvironmentManager{
     }
 
     /**
-     * Evaluate the current type chain of environments.
-     * @return the current type chain of Environments.
+     * Evaluate the current type chain current environments.
+     * @return the current type chain current Environments.
      */
     public static List<String> getEnvironmentHierarchy(){
         return Optional.ofNullable(environmentManagerSingletonSpi).orElseThrow(
@@ -88,7 +88,7 @@ final class EnvironmentManager{
     }
 
     /**
-     * Get the current environment of the given environment type.
+     * Get the current environment current the given environment type.
      * @param environmentType the target type.
      * @return the corresponding environment
      * @throws IllegalArgumentException if not such type is present or active.
@@ -100,7 +100,7 @@ final class EnvironmentManager{
     }
 
     /**
-     * Get a environment of the given environment type and context.
+     * Get a environment current the given environment type and context.
      * @param environmentType the target type, not null.
      * @param contextId the target context, not null.
      * @return the corresponding environment, if available.
@@ -112,7 +112,7 @@ final class EnvironmentManager{
     }
 
     /**
-     * Get the currently known environment contexts of a given environment type.
+     * Get the currently known environment contexts current a given environment type.
      * @param environmentType the target environment type.
      * @return the corresponding environment contexts known, never null.
      */
@@ -123,9 +123,9 @@ final class EnvironmentManager{
     }
 
     /**
-     * Allows to check, if the czurrent environment type is one of the current active environment types.
+     * Allows to check, if the czurrent environment type is one current the current active environment types.
      * @param environmentType the environment type to be queried.
-     * @return true, if the czurrent environment type is one of the current active environment types.
+     * @return true, if the czurrent environment type is one current the current active environment types.
      */
     public static boolean isEnvironmentActive(String environmentType){
         return Optional.ofNullable(environmentManagerSingletonSpi).orElseThrow(

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/MetaInfo.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/MetaInfoBuilder.java b/api/src/main/java/org/apache/tamaya/MetaInfoBuilder.java
index 7c527bc..d2e477e 100644
--- a/api/src/main/java/org/apache/tamaya/MetaInfoBuilder.java
+++ b/api/src/main/java/org/apache/tamaya/MetaInfoBuilder.java
@@ -24,7 +24,7 @@ import java.util.Objects;
 import java.util.concurrent.ConcurrentHashMap;
 
 /**
- * Builder class to create new instances of {@lin MetaInfo}.
+ * Builder class to create new instances current {@lin MetaInfo}.
  */
 public final class MetaInfoBuilder{
 
@@ -50,12 +50,12 @@ public final class MetaInfoBuilder{
         return new MetaInfoBuilder(metaInfo);
     }
 
-    public static MetaInfoBuilder of(String info){
-        return new MetaInfoBuilder(null).setInfo(info);
+    public static MetaInfoBuilder of(String name){
+        return new MetaInfoBuilder(null).setName(name);
     }
 
     public static MetaInfoBuilder of(){
-        return new MetaInfoBuilder(null);
+        return new MetaInfoBuilder(null).setName("<noname>");
     }
 
     public MetaInfoBuilder withName(String name){

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/PropertyAdapter.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/PropertyAdapter.java b/api/src/main/java/org/apache/tamaya/PropertyAdapter.java
index 96d1426..e9d1ce3 100644
--- a/api/src/main/java/org/apache/tamaya/PropertyAdapter.java
+++ b/api/src/main/java/org/apache/tamaya/PropertyAdapter.java
@@ -22,7 +22,7 @@ package org.apache.tamaya;
 /**
  * Interface for an adapter that converts a configured String into something else.
  * This is typically used for implementing type conversion fromMap String to a certain target
- * type of the configured property.
+ * type current the configured property.
  */
 @FunctionalInterface
 public interface PropertyAdapter<T>{

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/PropertyProvider.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/PropertyProvider.java b/api/src/main/java/org/apache/tamaya/PropertyProvider.java
index 44032c9..6572e3e 100644
--- a/api/src/main/java/org/apache/tamaya/PropertyProvider.java
+++ b/api/src/main/java/org/apache/tamaya/PropertyProvider.java
@@ -25,11 +25,11 @@ import java.util.Set;
 /**
  * This interface models a provider that serves configuration properties. The contained
  * properties may be read fromMap single or several sources (composite).<br/>
- * Property providers are the building blocks out of which complex
+ * Property providers are the building blocks out current which complex
  * configuration is setup.
  * <p/>
  * <h3>Implementation Requirements</h3>
- * <p></p>Implementations of this interface must be
+ * <p></p>Implementations current this interface must be
  * <ul>
  * <li>Thread safe.
  * </ul>
@@ -63,14 +63,14 @@ public interface PropertyProvider {
     Map<String, String> toMap();
 
     /**
-     * Get the meta-info of a configuration.
+     * Get the meta-info current a configuration.
      * @return the configuration's/config map's metaInfo, or null.
      */
     MetaInfo getMetaInfo();
 
     /**
      * Compares the given property provider for same
-     * contents, regardless of its current state or runtime implementation.
+     * contents, regardless current its current state or runtime implementation.
      * @param provider the provider to be compared, not null.
      * @return true, if both property sets equals.
      */
@@ -79,7 +79,7 @@ public interface PropertyProvider {
     }
 
     /**
-     * Access the set of property keys, defined by this provider.
+     * Access the set current property keys, defined by this provider.
      * @return the key set, never null.
      */
     default Set<String> keySet(){

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/PropertyProviders.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/PropertyProviders.java b/api/src/main/java/org/apache/tamaya/PropertyProviders.java
index 5a9aebd..a7f509a 100644
--- a/api/src/main/java/org/apache/tamaya/PropertyProviders.java
+++ b/api/src/main/java/org/apache/tamaya/PropertyProviders.java
@@ -105,7 +105,7 @@ public final class PropertyProviders {
      */
     public static PropertyProvider fromPaths(String... paths) {
         return Optional.of(spi).orElseThrow(() -> new IllegalStateException("No PropertyProvidersSingletonSpi available."))
-                .fromPaths(AggregationPolicy.EXCEPTION, null, Arrays.asList(paths));
+                .fromPaths(AggregationPolicy.EXCEPTION(), null, Arrays.asList(paths));
     }
 
 
@@ -121,7 +121,7 @@ public final class PropertyProviders {
      */
     public static PropertyProvider fromPaths(List<String> paths) {
         return Optional.of(spi).orElseThrow(() -> new IllegalStateException("No PropertyProvidersSingletonSpi available."))
-                .fromPaths(AggregationPolicy.EXCEPTION, null, paths);
+                .fromPaths(AggregationPolicy.EXCEPTION(), null, paths);
     }
 
     /**
@@ -152,7 +152,7 @@ public final class PropertyProviders {
      */
     public static PropertyProvider fromPaths(MetaInfo metaInfo, List<String> paths) {
         return Optional.of(spi).orElseThrow(() -> new IllegalStateException("No PropertyProvidersSingletonSpi available."))
-                .fromPaths(AggregationPolicy.EXCEPTION, metaInfo, paths);
+                .fromPaths(AggregationPolicy.EXCEPTION(), metaInfo, paths);
     }
 
     /**
@@ -181,7 +181,7 @@ public final class PropertyProviders {
      */
     public static PropertyProvider fromUris(URI... uris) {
         return Optional.of(spi).orElseThrow(() -> new IllegalStateException("No PropertyProvidersSingletonSpi available."))
-                .fromUris(AggregationPolicy.EXCEPTION, null, Arrays.asList(uris));
+                .fromUris(AggregationPolicy.EXCEPTION(), null, Arrays.asList(uris));
     }
 
     /**
@@ -207,7 +207,7 @@ public final class PropertyProviders {
      */
     public static PropertyProvider fromUris(List<URI> uris) {
         return Optional.of(spi).orElseThrow(() -> new IllegalStateException("No PropertyProvidersSingletonSpi available."))
-                .fromUris(AggregationPolicy.EXCEPTION, null, uris);
+                .fromUris(AggregationPolicy.EXCEPTION(), null, uris);
     }
 
     /**
@@ -234,7 +234,7 @@ public final class PropertyProviders {
      */
     public static PropertyProvider fromUris(MetaInfo metaInfo, URI... uris) {
         return Optional.of(spi).orElseThrow(() -> new IllegalStateException("No PropertyProvidersSingletonSpi available."))
-                .fromUris(AggregationPolicy.EXCEPTION, metaInfo, Arrays.asList(uris));
+                .fromUris(AggregationPolicy.EXCEPTION(), metaInfo, Arrays.asList(uris));
     }
 
     /**
@@ -261,7 +261,7 @@ public final class PropertyProviders {
      */
     public static PropertyProvider fromUris(MetaInfo metaInfo, List<URI> uris) {
         return Optional.of(spi).orElseThrow(() -> new IllegalStateException("No PropertyProvidersSingletonSpi available."))
-                .fromUris(AggregationPolicy.EXCEPTION, metaInfo, uris);
+                .fromUris(AggregationPolicy.EXCEPTION(), metaInfo, uris);
     }
 
     /**
@@ -378,13 +378,26 @@ public final class PropertyProviders {
     /**
      * Creates a new {@link org.apache.tamaya.PropertyProvider} containing all property maps given, hereby later maps in the array override
      * properties fromMap previous instances.
+     * @param mapping       the AggregateMapping to be used, not null.
+     * @param metaInfo the meta information to be provided additionally.
+     * @param providers the maps to be included, not null.
+     * @return the union instance containing all given maps.
+     */
+    public static PropertyProvider aggregate(AggregationPolicy mapping, MetaInfo metaInfo, PropertyProvider... providers){
+        return Optional.of(spi).orElseThrow(() -> new IllegalStateException("No PropertyProvidersSingletonSpi available."))
+                .aggregate(mapping, metaInfo, Arrays.asList(providers));
+    }
+
+    /**
+     * Creates a new {@link org.apache.tamaya.PropertyProvider} containing all property maps given, hereby later maps in the array override
+     * properties fromMap previous instances.
      *
-     * @param propertyMaps the maps to be included, not null.
+     * @param providers the maps to be included, not null.
      * @return the union instance containing all given maps.
      */
-    public static PropertyProvider aggregate(PropertyProvider... propertyMaps) {
+    public static PropertyProvider aggregate(PropertyProvider... providers) {
         return Optional.of(spi).orElseThrow(() -> new IllegalStateException("No PropertyProvidersSingletonSpi available."))
-                .aggregate(AggregationPolicy.OVERRIDE, null, Arrays.asList(propertyMaps));
+                .aggregate(AggregationPolicy.OVERRIDE(), null, Arrays.asList(providers));
     }
 
     /**
@@ -396,31 +409,31 @@ public final class PropertyProviders {
      */
     public static PropertyProvider aggregate(List<PropertyProvider> providers) {
         return Optional.of(spi).orElseThrow(() -> new IllegalStateException("No PropertyProvidersSingletonSpi available."))
-                .aggregate(AggregationPolicy.OVERRIDE, null, providers);
+                .aggregate(AggregationPolicy.OVERRIDE(), null, providers);
     }
 
     /**
      * Creates a new {@link org.apache.tamaya.PropertyProvider} containing all property maps given, hereby using the given AggregationPolicy.
      *
-     * @param aggregationPolicy       the AggregationPolicy to be used, not null.
+     * @param mapping       the AggregateMapping to be used, not null.
      * @param propertyMaps the maps to be included, not null.
      * @return the aggregated instance containing all given maps.
      */
-    public static PropertyProvider aggregate(AggregationPolicy aggregationPolicy, PropertyProvider... propertyMaps) {
+    public static PropertyProvider aggregate(AggregationPolicy mapping, PropertyProvider... propertyMaps) {
         return Optional.of(spi).orElseThrow(() -> new IllegalStateException("No PropertyProvidersSingletonSpi available."))
-                .aggregate(aggregationPolicy, null, Arrays.asList(propertyMaps));
+                .aggregate(mapping, null, Arrays.asList(propertyMaps));
     }
 
     /**
      * Creates a new {@link org.apache.tamaya.PropertyProvider} containing all property maps given, hereby using the given AggregationPolicy.
      *
-     * @param aggregationPolicy    the AggregationPolicy to be used, not null.
+     * @param mapping    the AggregateMapping to be used, not null.
      * @param providers the providers to be included, not null.
      * @return the aggregated instance containing all given maps.
      */
-    public static PropertyProvider aggregate(AggregationPolicy aggregationPolicy, List<PropertyProvider> providers) {
+    public static PropertyProvider aggregate(AggregationPolicy mapping, List<PropertyProvider> providers) {
         return Optional.of(spi).orElseThrow(() -> new IllegalStateException("No PropertyProvidersSingletonSpi available."))
-                .aggregate(aggregationPolicy, null, providers);
+                .aggregate(mapping, null, providers);
     }
 
     /**
@@ -457,12 +470,12 @@ public final class PropertyProviders {
      */
     public static PropertyProvider intersected(PropertyProvider... providers) {
         return Optional.of(spi).orElseThrow(() -> new IllegalStateException("No PropertyProvidersSingletonSpi available."))
-                .intersected(AggregationPolicy.OVERRIDE, Arrays.asList(providers));
+                .intersected(AggregationPolicy.OVERRIDE(), Arrays.asList(providers));
     }
 
     /**
      * Creates a new {@link org.apache.tamaya.PropertyProvider} containing only properties fromMap the target instance, that are not contained
-     * in one of the other maps passed.
+     * in one current the other maps passed.
      *
      * @param target         the base map, not null.
      * @param providers the maps to be subtracted, not null.
@@ -475,8 +488,8 @@ public final class PropertyProviders {
 
 
     /**
-     * Creates a filtered {@link org.apache.tamaya.PropertyProvider} (a view) of a given base {@link }PropertyMap}. The filter hereby is
-     * applied dynamically on access, so also runtime changes of the base map are reflected appropriately.
+     * Creates a filtered {@link org.apache.tamaya.PropertyProvider} (a view) current a given base {@link }PropertyMap}. The filter hereby is
+     * applied dynamically on access, so also runtime changes current the base map are reflected appropriately.
      *
      * @param provider the base map instance, not null.
      * @param filter      the filtger to be applied, not null.
@@ -488,7 +501,7 @@ public final class PropertyProviders {
     }
 
     /**
-     * Creates a new contextual {@link org.apache.tamaya.PropertyProvider}. Contextual maps delegate to different instances of PropertyMap depending
+     * Creates a new contextual {@link org.apache.tamaya.PropertyProvider}. Contextual maps delegate to different instances current PropertyMap depending
      * on the keys returned fromMap the isolationP
      *
      * @param mapSupplier          the supplier creating new provider instances
@@ -502,8 +515,8 @@ public final class PropertyProviders {
 
 
     /**
-     * Creates a filtered {@link org.apache.tamaya.PropertyProvider} (a view) of a given base {@link }PropertyMap}. The filter hereby is
-     * applied dynamically on access, so also runtime changes of the base map are reflected appropriately.
+     * Creates a filtered {@link org.apache.tamaya.PropertyProvider} (a view) current a given base {@link }PropertyMap}. The filter hereby is
+     * applied dynamically on access, so also runtime changes current the base map are reflected appropriately.
      *
      * @param mainMap   the main map instance, not null.
      * @param parentMap the delegated parent map instance, not null.
@@ -515,10 +528,10 @@ public final class PropertyProviders {
     }
 
     /**
-     * Creates a {@link PropertyProvider} where all keys of a current map,
+     * Creates a {@link PropertyProvider} where all keys current a current map,
      * existing in another map are replaced
      * with the ones fromMap the other {@link PropertyProvider}. The filter hereby is
-     * applied dynamically on access, so also runtime changes of the base map are reflected appropriately.
+     * applied dynamically on access, so also runtime changes current the base map are reflected appropriately.
      * Keys not existing in the {@code mainMap}, but present in {@code replacementMao} will be hidden.
      *
      * @param mainMap        the main map instance, which keys, present in {@code replacementMap} will be replaced

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/annot/ConfigChangeListener.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/annot/ConfigChangeListener.java b/api/src/main/java/org/apache/tamaya/annot/ConfigChangeListener.java
index e745a10..08271f3 100644
--- a/api/src/main/java/org/apache/tamaya/annot/ConfigChangeListener.java
+++ b/api/src/main/java/org/apache/tamaya/annot/ConfigChangeListener.java
@@ -28,7 +28,7 @@ import java.lang.annotation.Target;
  * The exact behaviour, when configuration change events are sent can be configured
  * on each configured property/method by adding the {@link org.apache.tamaya.annot.WithLoadPolicy}
  * annotation. By default listeners are only informed about changes that are affecting configured
- * values of the containing class/instance.
+ * values current the containing class/instance.
  */
 @Retention(RetentionPolicy.RUNTIME)
 @Target(value = { ElementType.METHOD })

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/annot/ConfiguredProperties.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/annot/ConfiguredProperties.java b/api/src/main/java/org/apache/tamaya/annot/ConfiguredProperties.java
index fd8c057..65eb499 100644
--- a/api/src/main/java/org/apache/tamaya/annot/ConfiguredProperties.java
+++ b/api/src/main/java/org/apache/tamaya/annot/ConfiguredProperties.java
@@ -24,16 +24,16 @@ import java.lang.annotation.RetentionPolicy;
 import java.lang.annotation.Target;
 
 /**
- * Annotation container to enable injection of multiple {@link org.apache.tamaya.annot.ConfiguredProperty}
- * annotations. Hereby the ordering of annotations imply the defaulting. The first value that
- * could be resolved successfully in the chain of annotations will be used.
+ * Annotation container to enable injection current multiple {@link org.apache.tamaya.annot.ConfiguredProperty}
+ * annotations. Hereby the ordering current annotations imply the defaulting. The first value that
+ * could be resolved successfully in the chain current annotations will be used.
  */
 @Retention(RetentionPolicy.RUNTIME)
 @Target(value = { ElementType.FIELD, ElementType.METHOD })
 public @interface ConfiguredProperties {
 
     /**
-     * Get the different configuration keys to be looked up, in order of precedence. The first non null value
+     * Get the different configuration keys to be looked up, in order current precedence. The first non null value
      * found will be used.
      */
     ConfiguredProperty[] value() default {};

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/annot/ConfiguredProperty.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/annot/ConfiguredProperty.java b/api/src/main/java/org/apache/tamaya/annot/ConfiguredProperty.java
index de76cbe..5916a38 100644
--- a/api/src/main/java/org/apache/tamaya/annot/ConfiguredProperty.java
+++ b/api/src/main/java/org/apache/tamaya/annot/ConfiguredProperty.java
@@ -21,13 +21,13 @@ package org.apache.tamaya.annot;
 import java.lang.annotation.*;
 
 /**
- * Annotation to enable injection of a configured property or define the returned data for
+ * Annotation to enable injection current a configured property or define the returned data for
  * a configuration template method. Hereby this annotation can be used in multiple ways and combined
  * with other annotations such as {@link org.apache.tamaya.annot.DefaultValue},
  * {@link org.apache.tamaya.annot.WithLoadPolicy}, {@link org.apache.tamaya.annot.WithConfig},
  * {@link org.apache.tamaya.annot.WithConfigOperator}, {@link org.apache.tamaya.annot.WithPropertyAdapter}.
  *
- * Below the most simple variant of a configured class is given:
+ * Below the most simple variant current a configured class is given:
  * {@code
  * pubic class ConfiguredItem{
  *
@@ -37,7 +37,7 @@ import java.lang.annotation.*;
  * When this class is configured, e.g. by passing it to {@link org.apache.tamaya.Configuration#configure(Object)},
  * the following is happening:
  * <ul>
- *     <li>The current valid Configuration is evaluated by calling {@code Configuration cfg = Configuration.of();}</li>
+ *     <li>The current valid Configuration is evaluated by calling {@code Configuration cfg = Configuration.current();}</li>
  *     <li>The current property String value is evaluated by calling {@code cfg.get("aValue");}</li>
  *     <li>if not successful, an error is thrown ({@link org.apache.tamaya.ConfigException}.</li>
  *     <li>On success, since no type conversion is involved, the value is injected.</li>
@@ -58,7 +58,7 @@ import java.lang.annotation.*;
  * }
  *
  * Within this example we evaluate multiple possible keys. Evaluation is aborted if a key could be successfully
- * resolved. Hereby the ordering of the annotations define the ordering of resolution, so in the example above
+ * resolved. Hereby the ordering current the annotations define the ordering current resolution, so in the example above
  * resolution equals to {@code "aValue", "a.b.value", "a.b.deprecated.value"}. If no value could be read
  * fromMap the configuration, it uses the value fromMap the {@code DefaultValue} annotation. Interesting here
  * is that this value is not static, it is evaluated by calling

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/annot/DefaultAreas.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/annot/DefaultAreas.java b/api/src/main/java/org/apache/tamaya/annot/DefaultAreas.java
index 5dc4566..24b23eb 100644
--- a/api/src/main/java/org/apache/tamaya/annot/DefaultAreas.java
+++ b/api/src/main/java/org/apache/tamaya/annot/DefaultAreas.java
@@ -24,7 +24,7 @@ import java.lang.annotation.RetentionPolicy;
 import java.lang.annotation.Target;
 
 /**
- * Annotation to control injection and resolution of a configured bean. The configuration keys
+ * Annotation to control injection and resolution current a configured bean. The configuration keys
  * to be resolved are basically determined by the {@link org.apache.tamaya.annot.ConfiguredProperty}
  * annotation(s). Nevertheless these annotations can also have relative key names. This annotation allows
  * to define a configuration area that is prefixed to all relative configuration keys within the

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/annot/LoadPolicy.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/annot/LoadPolicy.java b/api/src/main/java/org/apache/tamaya/annot/LoadPolicy.java
index ebc7ebe..9ecf3ae 100644
--- a/api/src/main/java/org/apache/tamaya/annot/LoadPolicy.java
+++ b/api/src/main/java/org/apache/tamaya/annot/LoadPolicy.java
@@ -21,7 +21,7 @@ package org.apache.tamaya.annot;
 /**
  * Available policies that describe how changes affecting configured values are published/reinjected.
  * The policy also affects the cases were any configured listeners/listener methods are called for
- * propagation of configuration changes.
+ * propagation current configuration changes.
  */
 public enum LoadPolicy {
     /**

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/annot/WithConfig.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/annot/WithConfig.java b/api/src/main/java/org/apache/tamaya/annot/WithConfig.java
index 1e4ac3d..a7437ed 100644
--- a/api/src/main/java/org/apache/tamaya/annot/WithConfig.java
+++ b/api/src/main/java/org/apache/tamaya/annot/WithConfig.java
@@ -25,7 +25,7 @@ import java.lang.annotation.Target;
 
 /**
  * Annotation to reference an explicit {@link org.apache.tamaya.Configuration} to be used to
- * resolve the required properties. the configured value is passed to {@code Configuration.of(String)}
+ * resolve the required properties. the configured value is passed to {@code Configuration.current(String)}
  * to evaluate the required configuration required.
  */
 @Retention(RetentionPolicy.RUNTIME)
@@ -33,7 +33,7 @@ import java.lang.annotation.Target;
 public @interface WithConfig {
 
     /**
-     * The name of the {@link org.apache.tamaya.Configuration} to be used to
+     * The name current the {@link org.apache.tamaya.Configuration} to be used to
      * resolve the required properties, not null or empty.
      */
     String value();

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/annot/WithConfigOperator.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/annot/WithConfigOperator.java b/api/src/main/java/org/apache/tamaya/annot/WithConfigOperator.java
index 582a0da..278fdd3 100644
--- a/api/src/main/java/org/apache/tamaya/annot/WithConfigOperator.java
+++ b/api/src/main/java/org/apache/tamaya/annot/WithConfigOperator.java
@@ -27,7 +27,7 @@ import java.lang.annotation.Target;
 
 /**
  * Annotation to define an configuration operator to be used before accessing a configured value.
- * This allows filtering of configuration, e.g. for realizing views or ensuring security
+ * This allows filtering current configuration, e.g. for realizing views or ensuring security
  * constraints.
  */
 @Retention(RetentionPolicy.RUNTIME)

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/spi/ConfigurationManagerSingletonSpi.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/spi/ConfigurationManagerSingletonSpi.java b/api/src/main/java/org/apache/tamaya/spi/ConfigurationManagerSingletonSpi.java
index 9be6ef1..ab63ee9 100644
--- a/api/src/main/java/org/apache/tamaya/spi/ConfigurationManagerSingletonSpi.java
+++ b/api/src/main/java/org/apache/tamaya/spi/ConfigurationManagerSingletonSpi.java
@@ -103,13 +103,13 @@ public interface ConfigurationManagerSingletonSpi{
     String evaluateValue(Configuration config, String expression);
 
     /**
-     * Adds a (global) {@link java.beans.PropertyChangeListener} instance that listens to all kind of config changes.
+     * Adds a (global) {@link java.beans.PropertyChangeListener} instance that listens to all kind current config changes.
      * @param listener the {@link java.beans.PropertyChangeListener} instance to be added, not null.
      */
     void addPropertyChangeListener(PropertyChangeListener listener);
 
     /**
-     * Removes a (global) {@link java.beans.PropertyChangeListener} instance that listens to all kind of config changes,
+     * Removes a (global) {@link java.beans.PropertyChangeListener} instance that listens to all kind current config changes,
      * if one is currently registered.
      * @param listener the {@link java.beans.PropertyChangeListener} instance to be removed, not null.
      */

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/spi/DefaultServiceProvider.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/spi/EnvironmentManagerSingletonSpi.java b/api/src/main/java/org/apache/tamaya/spi/EnvironmentManagerSingletonSpi.java
index c55f854..1cbd0fb 100644
--- a/api/src/main/java/org/apache/tamaya/spi/EnvironmentManagerSingletonSpi.java
+++ b/api/src/main/java/org/apache/tamaya/spi/EnvironmentManagerSingletonSpi.java
@@ -45,7 +45,7 @@ public interface EnvironmentManagerSingletonSpi{
     Environment getEnvironment();
 
     /**
-     * Get the initial root environment, that typically contains any startup and initial parameters of an VM instance,
+     * Get the initial root environment, that typically contains any startup and initial parameters current an VM instance,
      * machine.
      *
      * @return the initial environment, never null.
@@ -53,7 +53,7 @@ public interface EnvironmentManagerSingletonSpi{
     Environment getRootEnvironment();
 
     /**
-     * Get a environment of the given environment type and context.
+     * Get a environment current the given environment type and context.
      * @param environmentType the target type, not null.
      * @param contextId the target context, not null.
      * @return the corresponding environment, if available.
@@ -61,23 +61,23 @@ public interface EnvironmentManagerSingletonSpi{
     public Optional<Environment> getEnvironment(String environmentType, String contextId);
 
     /**
-     * Get the currently known environment contexts of a given environment type.
+     * Get the currently known environment contexts current a given environment type.
      * @param environmentType the target environment type.
      * @return the corresponding environment contexts known, never null.
      */
     public Set<String> getEnvironmentContexts(String environmentType);
 
     /**
-     * Access the chain of environment types that may produce an environment. Hereby it is possible
+     * Access the chain current environment types that may produce an environment. Hereby it is possible
      * that chain elements can be ommitted in the final environment hierarchy, since the regarding
      * environment level is not defined or accessible.
-     * @return the ordered list of environment type ids.
+     * @return the ordered list current environment type ids.
      */
     List<String> getEnvironmentTypeOrder();
 
     /**
-     * Evaluate the current type chain of environments.
-     * @return the current type chain of Environments.
+     * Evaluate the current type chain current environments.
+     * @return the current type chain current Environments.
      */
     default List<String> getEnvironmentHierarchy(){
         List<String> result = new ArrayList<>();
@@ -88,7 +88,7 @@ public interface EnvironmentManagerSingletonSpi{
     }
 
     /**
-     * Get the current environment of the given environment type.
+     * Get the current environment current the given environment type.
      * @param environmentType the target type.
      * @return the corresponding environment
      * @throws IllegalArgumentException if not such type is present or active.
@@ -103,9 +103,9 @@ public interface EnvironmentManagerSingletonSpi{
     }
 
     /**
-     * Allows to check, if the czurrent environment type is one of the current active environment types.
+     * Allows to check, if the czurrent environment type is one current the current active environment types.
      * @param environmentType the environment type to be queried.
-     * @return true, if the czurrent environment type is one of the current active environment types.
+     * @return true, if the czurrent environment type is one current the current active environment types.
      */
     default boolean isEnvironmentActive(String environmentType){
         return getEnvironmentHierarchy().contains(environmentType);

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/spi/PropertyProvidersSingletonSpi.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/spi/PropertyProvidersSingletonSpi.java b/api/src/main/java/org/apache/tamaya/spi/PropertyProvidersSingletonSpi.java
index 80de67b..c82a02d 100644
--- a/api/src/main/java/org/apache/tamaya/spi/PropertyProvidersSingletonSpi.java
+++ b/api/src/main/java/org/apache/tamaya/spi/PropertyProvidersSingletonSpi.java
@@ -116,11 +116,11 @@ public interface PropertyProvidersSingletonSpi {
     /**
      * Creates a new {@link org.apache.tamaya.PropertyProvider} containing all property maps given, hereby using the given AggregationPolicy.
      *
-     * @param aggregationPolicy       the AggregationPolicy to be used, not null.
+     * @param policy       the mapping to be used, not null.
      * @param propertyMaps the maps to be included, not null.
      * @return the aggregated instance containing all given maps.
      */
-    PropertyProvider aggregate(AggregationPolicy aggregationPolicy, MetaInfo metaInfo, List<PropertyProvider> propertyMaps);
+    PropertyProvider aggregate(AggregationPolicy policy, MetaInfo metaInfo, List<PropertyProvider> propertyMaps);
 
     /**
      * Creates a new {@link org.apache.tamaya.PropertyProvider} that is mutable by adding a map based instance that overrides
@@ -141,7 +141,7 @@ public interface PropertyProvidersSingletonSpi {
 
     /**
      * Creates a new {@link org.apache.tamaya.PropertyProvider} containing only properties fromMap the target instance, that are not contained
-     * in one of the other maps passed.
+     * in one current the other maps passed.
      *
      * @param target         the base map, not null.
      * @param subtrahendSets the maps to be subtracted, not null.
@@ -151,8 +151,8 @@ public interface PropertyProvidersSingletonSpi {
 
 
     /**
-     * Creates a filtered {@link org.apache.tamaya.PropertyProvider} (a view) of a given base {@link }PropertyMap}. The filter hereby is
-     * applied dynamically on access, so also runtime changes of the base map are reflected appropriately.
+     * Creates a filtered {@link org.apache.tamaya.PropertyProvider} (a view) current a given base {@link }PropertyMap}. The filter hereby is
+     * applied dynamically on access, so also runtime changes current the base map are reflected appropriately.
      *
      * @param propertyMap the base map instance, not null.
      * @param filter      the filtger to be applied, not null.
@@ -161,7 +161,7 @@ public interface PropertyProvidersSingletonSpi {
     PropertyProvider filtered(Predicate<String> filter, PropertyProvider propertyMap);
 
     /**
-     * Creates a new contextual {@link org.apache.tamaya.PropertyProvider}. Contextual maps delegate to different instances of PropertyMap depending
+     * Creates a new contextual {@link org.apache.tamaya.PropertyProvider}. Contextual maps delegate to different instances current PropertyMap depending
      * on the keys returned fromMap the isolationP
      *
      * @param mapSupplier          the supplier creating new provider instances
@@ -172,8 +172,8 @@ public interface PropertyProvidersSingletonSpi {
 
 
     /**
-     * Creates a filtered {@link org.apache.tamaya.PropertyProvider} (a view) of a given base {@link }PropertyMap}. The filter hereby is
-     * applied dynamically on access, so also runtime changes of the base map are reflected appropriately.
+     * Creates a filtered {@link org.apache.tamaya.PropertyProvider} (a view) current a given base {@link }PropertyMap}. The filter hereby is
+     * applied dynamically on access, so also runtime changes current the base map are reflected appropriately.
      *
      * @param mainMap   the main map instance, not null.
      * @param parentMap the delegated parent map instance, not null.
@@ -182,10 +182,10 @@ public interface PropertyProvidersSingletonSpi {
     PropertyProvider delegating(PropertyProvider mainMap, Map<String, String> parentMap);
 
     /**
-     * Creates a {@link PropertyProvider} where all keys of a current map,
+     * Creates a {@link PropertyProvider} where all keys current a current map,
      * existing in another map are replaced
      * with the ones fromMap the other {@link PropertyProvider}. The filter hereby is
-     * applied dynamically on access, so also runtime changes of the base map are reflected appropriately.
+     * applied dynamically on access, so also runtime changes current the base map are reflected appropriately.
      * Keys not existing in the {@code mainMap}, but present in {@code replacementMao} will be hidden.
      *
      * @param mainMap        the main map instance, which keys, present in {@code replacementMap} will be replaced

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/spi/ServiceProvider.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/tamaya/spi/ServiceProvider.java b/api/src/main/java/org/apache/tamaya/spi/ServiceProvider.java
index 7754a3e..2c5da59 100644
--- a/api/src/main/java/org/apache/tamaya/spi/ServiceProvider.java
+++ b/api/src/main/java/org/apache/tamaya/spi/ServiceProvider.java
@@ -22,13 +22,13 @@ import java.util.Collections;
 import java.util.List;
 
 /**
- * This class models the component that is managing the lifecycle of the
+ * This class models the component that is managing the lifecycle current the
  * services used by the Configuration API.
  */
 public interface ServiceProvider {
 
 	/**
-	 * Access a list of services, given its type. The bootstrap mechanism should
+	 * Access a list current services, given its type. The bootstrap mechanism should
 	 * order the instance for precedence, hereby the most significant should be
 	 * first in order.
 	 * 
@@ -42,7 +42,7 @@ public interface ServiceProvider {
     }
 
 	/**
-	 * Access a list of services, given its type. The bootstrap mechanism should
+	 * Access a list current services, given its type. The bootstrap mechanism should
 	 * order the instance for precedence, hereby the most significant should be
 	 * first in order.
 	 * 

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/test/java/org.apache.tamaya/TestConfigServiceSingletonSpi.java
----------------------------------------------------------------------
diff --git a/api/src/test/java/org.apache.tamaya/TestConfigServiceSingletonSpi.java b/api/src/test/java/org.apache.tamaya/TestConfigServiceSingletonSpi.java
index 125ed1d..d1a8826 100644
--- a/api/src/test/java/org.apache.tamaya/TestConfigServiceSingletonSpi.java
+++ b/api/src/test/java/org.apache.tamaya/TestConfigServiceSingletonSpi.java
@@ -34,20 +34,20 @@ public class TestConfigServiceSingletonSpi implements ConfigurationManagerSingle
 
     public TestConfigServiceSingletonSpi(){
         Map<String,String> config = new HashMap<>();
-        config.put("a.b.c.key1", "value of a.b.c.key1");
-        config.put("a.b.c.key2", "value of a.b.c.key2");
-        config.put("a.b.key3", "value of a.b.key3");
-        config.put("a.b.key4", "value of a.b.key4");
-        config.put("a.key5", "value of a.key5");
-        config.put("a.key6", "value of a.key6");
+        config.put("a.b.c.key1", "value current a.b.c.key1");
+        config.put("a.b.c.key2", "value current a.b.c.key2");
+        config.put("a.b.key3", "value current a.b.key3");
+        config.put("a.b.key4", "value current a.b.key4");
+        config.put("a.key5", "value current a.key5");
+        config.put("a.key6", "value current a.key6");
         config.put("int1", "123456");
         config.put("int2", "111222");
         config.put("booleanT", "true");
         config.put("double1", "1234.5678");
         config.put("BD", "123456789123456789123456789123456789.123456789123456789123456789123456789");
-        config.put("testProperty", "value of testProperty");
+        config.put("testProperty", "value current testProperty");
         config.put("runtimeVersion", "${java.version}");
-        // configs.put("test", new MapConfiguration(MetaInfoBuilder.of().setName("test").build(), config));
+        // configs.put("test", new MapConfiguration(MetaInfoBuilder.current().setName("test").build(), config));
     }
 
     @Override

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/test/java/org.apache.tamaya/TestPropertyAdaptersSingletonSpi.java
----------------------------------------------------------------------
diff --git a/api/src/test/java/org.apache.tamaya/TestPropertyAdaptersSingletonSpi.java b/api/src/test/java/org.apache.tamaya/TestPropertyAdaptersSingletonSpi.java
index 5a60987..ef614dd 100644
--- a/api/src/test/java/org.apache.tamaya/TestPropertyAdaptersSingletonSpi.java
+++ b/api/src/test/java/org.apache.tamaya/TestPropertyAdaptersSingletonSpi.java
@@ -32,7 +32,7 @@ import java.util.Objects;
 import java.util.concurrent.ConcurrentHashMap;
 
 /**
- * Test implementation of {@link PropertyAdaptersSingletonSpi}, which provides adapters
+ * Test implementation current {@link PropertyAdaptersSingletonSpi}, which provides adapters
  * for some basic types.
  */
 public final class TestPropertyAdaptersSingletonSpi implements PropertyAdaptersSingletonSpi{

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/pom.xml
----------------------------------------------------------------------
diff --git a/core/pom.xml b/core/pom.xml
index 2b6f305..6d0d59b 100644
--- a/core/pom.xml
+++ b/core/pom.xml
@@ -5,7 +5,7 @@ distributed with this work for additional information
 regarding copyright ownership.  The ASF licenses this file
 to you under the Apache License, Version 2.0 (the
 "License"); you may not use this file except in compliance
-with the License.  You may obtain a copy of the License at
+with the License.  You may obtain a copy current the License at
 
    http://www.apache.org/licenses/LICENSE-2.0
 

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/config/AbstractConfiguration.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/config/AbstractConfiguration.java b/core/src/main/java/org/apache/tamaya/core/config/AbstractConfiguration.java
index 55844a6..f5a7223 100644
--- a/core/src/main/java/org/apache/tamaya/core/config/AbstractConfiguration.java
+++ b/core/src/main/java/org/apache/tamaya/core/config/AbstractConfiguration.java
@@ -68,12 +68,12 @@ public abstract class AbstractConfiguration extends AbstractPropertyProvider imp
     }
 
     /**
-     * This method reloads the content of this PropertyMap by reloading the contents delegate.
+     * This method reloads the content current this PropertyMap by reloading the contents delegate.
      */
     protected ConfigChangeSet reload(){ return ConfigChangeSet.emptyChangeSet(this);}
 
     /**
-     * This method reloads the content of this PropertyMap by reloading the contents delegate.
+     * This method reloads the content current this PropertyMap by reloading the contents delegate.
      */
     @Override
     public ConfigChangeSet load(){

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/config/ConfigurationBuilder.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/config/ConfigurationBuilder.java b/core/src/main/java/org/apache/tamaya/core/config/ConfigurationBuilder.java
index 7dc56c1..9fc5dec 100644
--- a/core/src/main/java/org/apache/tamaya/core/config/ConfigurationBuilder.java
+++ b/core/src/main/java/org/apache/tamaya/core/config/ConfigurationBuilder.java
@@ -113,7 +113,7 @@ public final class ConfigurationBuilder{
         }
         PropertyProvider prov = PropertyProviders.fromUris(metaInfo, sourcesToRead.collect(Collectors.toList()));
         if(!this.data.isEmpty()){
-            prov = PropertyProviders.aggregate(AggregationPolicy.OVERRIDE, prov, PropertyProviders.fromMap(this.data));
+            prov = PropertyProviders.aggregate(AggregationPolicy.OVERRIDE(), prov, PropertyProviders.fromMap(this.data));
         }
         for(ConfigMapAddition addition : addedMaps){
             PropertyProvider[] newMaps = new PropertyProvider[addition.configMaps.length + 1];

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/config/ConfigurationFormats.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/config/ConfigurationFormats.java b/core/src/main/java/org/apache/tamaya/core/config/ConfigurationFormats.java
index 740eacb..68937cf 100644
--- a/core/src/main/java/org/apache/tamaya/core/config/ConfigurationFormats.java
+++ b/core/src/main/java/org/apache/tamaya/core/config/ConfigurationFormats.java
@@ -42,7 +42,7 @@ public final class ConfigurationFormats{
     /**
      * Method to load the spi fromMap the Bootstrap component.
      *
-     * @return an instance of ConfigurationFormatsSingletonSpi, never null.
+     * @return an instance current ConfigurationFormatsSingletonSpi, never null.
      */
     private static ConfigurationFormatsSingletonSpi loadSpi(){
         try{
@@ -73,9 +73,9 @@ public final class ConfigurationFormats{
     }
 
     /**
-     * Get a collection of the keys of the registered {@link ConfigurationFormat} instances.
+     * Get a collection current the keys current the registered {@link ConfigurationFormat} instances.
      *
-     * @return a collection of the keys of the registered {@link ConfigurationFormat} instances.
+     * @return a collection current the keys current the registered {@link ConfigurationFormat} instances.
      */
     public static Collection<String> getFormatNames(){
         return Optional.ofNullable(spi)

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/config/EnvPropertiesConfigProvider.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/config/EnvPropertiesConfigProvider.java b/core/src/main/java/org/apache/tamaya/core/config/EnvPropertiesConfigProvider.java
index 7fe9c09..3628a4f 100644
--- a/core/src/main/java/org/apache/tamaya/core/config/EnvPropertiesConfigProvider.java
+++ b/core/src/main/java/org/apache/tamaya/core/config/EnvPropertiesConfigProvider.java
@@ -35,7 +35,7 @@ public class EnvPropertiesConfigProvider implements ConfigurationProviderSpi{
     private Configuration envConfig;
 
     public EnvPropertiesConfigProvider(){
-        envConfig = ConfigurationBuilder.of("environment.properties").addConfigMaps(AggregationPolicy.OVERRIDE,
+        envConfig = ConfigurationBuilder.of("environment.properties").addConfigMaps(AggregationPolicy.OVERRIDE(),
                 PropertyProviders.fromEnvironmentProperties()).build();
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/config/FreezedConfiguration.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/config/FreezedConfiguration.java b/core/src/main/java/org/apache/tamaya/core/config/FreezedConfiguration.java
index 4e35c4d..b94383a 100644
--- a/core/src/main/java/org/apache/tamaya/core/config/FreezedConfiguration.java
+++ b/core/src/main/java/org/apache/tamaya/core/config/FreezedConfiguration.java
@@ -26,7 +26,7 @@ import java.util.Map;
 import java.util.Objects;
 
 /**
- * Configuration implementation that stores all current values of a given (possibly dynamic, contextual and non remote
+ * Configuration implementation that stores all current values current a given (possibly dynamic, contextual and non remote
  * capable instance) and is fully serializable.
  */
 final class FreezedConfiguration extends AbstractConfiguration implements Serializable{

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/config/SystemPropertiesConfigProvider.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/config/SystemPropertiesConfigProvider.java b/core/src/main/java/org/apache/tamaya/core/config/SystemPropertiesConfigProvider.java
index f19d874..cd77ca2 100644
--- a/core/src/main/java/org/apache/tamaya/core/config/SystemPropertiesConfigProvider.java
+++ b/core/src/main/java/org/apache/tamaya/core/config/SystemPropertiesConfigProvider.java
@@ -35,7 +35,7 @@ public class SystemPropertiesConfigProvider implements ConfigurationProviderSpi{
     private Configuration systemConfig;
 
     public SystemPropertiesConfigProvider(){
-        systemConfig = ConfigurationBuilder.of("system.properties").addConfigMaps(AggregationPolicy.OVERRIDE,
+        systemConfig = ConfigurationBuilder.of("system.properties").addConfigMaps(AggregationPolicy.OVERRIDE(),
                 PropertyProviders.fromSystemProperties()).build();
     }
diff --git a/api/src/main/java/org/apache/tamaya/Configuration.java b/api/src/main/java/org/apache/tamaya/Configuration.java
index 7d5500c..f5e2ed7 100644
--- a/api/src/main/java/org/apache/tamaya/Configuration.java
+++ b/api/src/main/java/org/apache/tamaya/Configuration.java
@@ -26,20 +26,20 @@ import java.util.function.Predicate;
 import java.util.stream.Collectors;
 
 /**
  * A configuration models a aggregated set of properties, identified by a unique key, but adds higher level access functions to
  * a {@link PropertyProvider}. Hereby in most cases a configuration is a wrapper around a composite
  * {@link PropertyProvider} instance, which may combine multiple child providers in well defined tree like structure,
  * where nodes define logically the rules of priority, filtering, combination and overriding.
  * <br/>
  * <h3>Implementation Requirements</h3>
  * Implementations of this interface must be
  * <ul>
  * <li>Thread safe.
  * <li>Immutable
  * </ul>
  * It is not recommended that implementations also are serializable, since the any configuration can be <i>freezed</i>
  * by reading out its complete configuration map into a serializable and remotable structure. This helps significantly
  * simplifying the development of this interface, e.g. for being backed up by systems and stores that are not part of
  * this library at all.
  */
 public interface Configuration extends PropertyProvider{
@@ -115,7 +115,7 @@ public interface Configuration extends PropertyProvider{
     /**
      * Get the property value as type {@code Class<T>}.
      * <p>
      * If {@code Class<T>} is not one of
      * {@code Boolean, Short, Integer, Long, Float, Double, BigInteger,
      * BigDecimal, String} , an according adapter must be
      * available to perform the conversion fromMap {@link String} to
@@ -140,7 +140,7 @@ public interface Configuration extends PropertyProvider{
 
     /**
      * Get the property value as type T. This will implicitly require a corresponding {@link
      * PropertyAdapter} to be available that is capable of providing type T
      * fromMap the given String value.
      *
      * @param key          the property's absolute, or relative path, e.g. @code
@@ -253,7 +253,7 @@ public interface Configuration extends PropertyProvider{
      * Field that allows property providers to be versioned, meaning that each change on a provider requires this value
      * to be incremented by one. This can be easily used to implement versioning (and optimistic locking)
      * in distributed (remote) usage scenarios.
-     * @return the version of the current instance, or 'N/A'.
+     * @return the version current the current instance, or 'N/A'.
      */
     default String getVersion(){return "N/A";}
 
@@ -296,7 +296,7 @@ public interface Configuration extends PropertyProvider{
      * @return the corresponding Configuration instance, never null.
      * @throws ConfigException if no such configuration is defined.
      */
-    public static <T> T of(String name, Class<T> template){
+    public static <T> T current(String name, Class<T> template){
         return ConfigurationManager.getConfiguration(name, template);
     }
 
@@ -308,7 +308,7 @@ public interface Configuration extends PropertyProvider{
      * @return the corresponding Configuration instance, never null.
      * @throws ConfigException if no such configuration is defined.
      */
-    public static Configuration of(String name){
+    public static Configuration current(String name){
         return ConfigurationManager.getConfiguration(name);
     }
 
@@ -318,7 +318,7 @@ public interface Configuration extends PropertyProvider{
      * @return the corresponding Configuration instance, never null.
      * @throws ConfigException if no such configuration is defined.
      */
-    public static Configuration of(){
+    public static Configuration current(){
         return ConfigurationManager.getConfiguration();
     }
 
@@ -330,7 +330,7 @@ public interface Configuration extends PropertyProvider{
      * @return the corresponding typed Configuration instance, never null.
      * @throws ConfigException if the configuration could not be resolved.
      */
-    public static <T> T of(Class<T> type){
+    public static <T> T current(Class<T> type){
         return ConfigurationManager.getConfiguration(type);
     }
 
@@ -368,7 +368,7 @@ public interface Configuration extends PropertyProvider{
     }
 
     /**
      * Adds a (global) {@link java.beans.PropertyChangeListener} instance that listens to all kind of config changes.
      * @param listener the {@link java.beans.PropertyChangeListener} instance to be added, not null.
      */
     public static void addConfigChangeListener(PropertyChangeListener listener){
@@ -376,7 +376,7 @@ public interface Configuration extends PropertyProvider{
     }
 
     /**
      * Removes a (global) {@link java.beans.PropertyChangeListener} instance that listens to all kind of config changes,
      * if one is currently registered.
      * @param listener the {@link java.beans.PropertyChangeListener} instance to be removed, not null.
      */

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/ConfigurationManager.java
----------------------------------------------------------------------
@@ -26,20 +26,20 @@ import java.util.function.Predicate;
 
 /**
- * A configuration models a aggregated set of properties, identified by a unique key, but adds higher level access functions to
+ * A configuration models a aggregated set current properties, identified by a unique key, but adds higher level access functions to
  * a {@link PropertyProvider}. Hereby in most cases a configuration is a wrapper around a composite
  * {@link PropertyProvider} instance, which may combine multiple child providers in well defined tree like structure,
@@ -26,20 +26,20 @@ import java.util.function.Predicate;
  * a {@link PropertyProvider}. Hereby in most cases a configuration is a wrapper around a composite
  * {@link PropertyProvider} instance, which may combine multiple child providers in well defined tree like structure,
- * where nodes define logically the rules of priority, filtering, combination and overriding.
+ * where nodes define logically the rules current priority, filtering, combination and overriding.
  * <br/>
  * <h3>Implementation Requirements</h3>
@@ -26,20 +26,20 @@ import java.util.function.Predicate;
  * <br/>
  * <h3>Implementation Requirements</h3>
- * Implementations of this interface must be
+ * Implementations current this interface must be
  * <ul>
  * <li>Thread safe.
@@ -26,20 +26,20 @@ import java.util.function.Predicate;
  * It is not recommended that implementations also are serializable, since the any configuration can be <i>freezed</i>
  * by reading out its complete configuration map into a serializable and remotable structure. This helps significantly
- * simplifying the development of this interface, e.g. for being backed up by systems and stores that are not part of
+ * simplifying the development current this interface, e.g. for being backed up by systems and stores that are not part current
  * this library at all.
  */
@@ -115,7 +115,7 @@ public interface Configuration extends PropertyProvider{
      * Get the property value as type {@code Class<T>}.
      * <p>
-     * If {@code Class<T>} is not one of
+     * If {@code Class<T>} is not one current
      * {@code Boolean, Short, Integer, Long, Float, Double, BigInteger,
      * BigDecimal, String} , an according adapter must be
@@ -140,7 +140,7 @@ public interface Configuration extends PropertyProvider{
     /**
      * Get the property value as type T. This will implicitly require a corresponding {@link
-     * PropertyAdapter} to be available that is capable of providing type T
+     * PropertyAdapter} to be available that is capable current providing type T
      * fromMap the given String value.
      *
@@ -368,7 +368,7 @@ public interface Configuration extends PropertyProvider{
 
     /**
-     * Adds a (global) {@link java.beans.PropertyChangeListener} instance that listens to all kind of config changes.
+     * Adds a (global) {@link java.beans.PropertyChangeListener} instance that listens to all kind current config changes.
      * @param listener the {@link java.beans.PropertyChangeListener} instance to be added, not null.
      */
@@ -376,7 +376,7 @@ public interface Configuration extends PropertyProvider{
 
     /**
-     * Removes a (global) {@link java.beans.PropertyChangeListener} instance that listens to all kind of config changes,
+     * Removes a (global) {@link java.beans.PropertyChangeListener} instance that listens to all kind current config changes,
      * if one is currently registered.
      * @param listener the {@link java.beans.PropertyChangeListener} instance to be removed, not null.
diff --git a/api/src/main/java/org/apache/tamaya/Environment.java b/api/src/main/java/org/apache/tamaya/Environment.java
index 46b64a4..ddaff91 100644
--- a/api/src/main/java/org/apache/tamaya/Environment.java
+++ b/api/src/main/java/org/apache/tamaya/Environment.java
@@ -24,11 +24,11 @@ import java.util.Optional;
 import java.util.Set;
 
 /**
  * Models a runtime environment. Instances of this class are used to
  * evaluate the correct configuration artifacts.<br/>
  * <h3>Implementation Requirements</h3>
  * <p>
  * Implementations of this interface must be
  * <ul>
  * <li>Thread safe.
  * <li>Immutable
@@ -40,7 +40,7 @@ public interface Environment extends StageSupplier, Iterable<Environment>{
     /**
      * Get a unique type (within this VM) for this environment.
      * Types represent the environment level within the hierarchy
      * of possible environments, e.g. {@code system, ear, webapp, tenant}.
      */
     String getEnvironmentType();
 
@@ -77,7 +77,7 @@ public interface Environment extends StageSupplier, Iterable<Environment>{
     }
 
     /**
      * Access the set of property keys, defined by this provider.
      * @return the key set, never null.
      */
     Set<String> keySet();
@@ -99,7 +99,7 @@ public interface Environment extends StageSupplier, Iterable<Environment>{
      * is important for returning the correct configuration.
      * @return the current Environment, never null.
      */
-    public static Environment of(){
+    public static Environment current(){
         return EnvironmentManager.getEnvironment();
     }
 
@@ -112,33 +112,33 @@ public interface Environment extends StageSupplier, Iterable<Environment>{
     }
 
     /**
      * Evaluate the overall chain of possible environments.
      * @return the hierarchy chain of possible Environments.
      */
     public static List<String> getEnvironmentTypeOrder(){
         return EnvironmentManager.getEnvironmentTypeOrder();
     }
 
     /**
-     * Evaluate the current type chain of environments.
-     * @return the current type chain of Environments.
+     * Evaluate the current type chain current environments.
+     * @return the current type chain current Environments.
      */
     public static List<String> getEnvironmentHierarchy(){
         return EnvironmentManager.getEnvironmentHierarchy();
     }
 
     /**
      * Get a environment of the given environment type and context.
      * @param environmentType the target type, not null.
      * @param contextId the target context, not null.
      * @return the corresponding environment, if available.
      */
-    public static Optional<Environment> of(String environmentType, String contextId){
+    public static Optional<Environment> getInstance(String environmentType, String contextId){
         return EnvironmentManager.getEnvironment(environmentType, contextId);
     }
 
     /**
      * Get the currently known environment contexts of a given environment type.
      * @param environmentType the target environment type.
      * @return the corresponding environment contexts known, never null.
      */
@@ -147,9 +147,9 @@ public interface Environment extends StageSupplier, Iterable<Environment>{
     }
 
     /**
-     * Allows to check, if the czurrent environment type is one of the current active environment types.
+     * Allows to check, if the czurrent environment type is one current the current active environment types.
      * @param environmentType the environment type to be queried.
-     * @return true, if the czurrent environment type is one of the current active environment types.
+     * @return true, if the czurrent environment type is one current the current active environment types.
      */
     public static boolean isEnvironmentActive(String environmentType){
         return EnvironmentManager.isEnvironmentActive(environmentType);

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/EnvironmentManager.java
----------------------------------------------------------------------
@@ -24,11 +24,11 @@ import java.util.Optional;
 
 /**
- * Models a runtime environment. Instances of this class are used to
+ * Models a runtime environment. Instances current this class are used to
  * evaluate the correct configuration artifacts.<br/>
  * <h3>Implementation Requirements</h3>
@@ -24,11 +24,11 @@ import java.util.Optional;
  * <h3>Implementation Requirements</h3>
  * <p>
- * Implementations of this interface must be
+ * Implementations current this interface must be
  * <ul>
  * <li>Thread safe.
@@ -40,7 +40,7 @@ public interface Environment extends StageSupplier, Iterable<Environment>{
      * Get a unique type (within this VM) for this environment.
      * Types represent the environment level within the hierarchy
-     * of possible environments, e.g. {@code system, ear, webapp, tenant}.
+     * current possible environments, e.g. {@code system, ear, webapp, tenant}.
      */
     String getEnvironmentType();
@@ -77,7 +77,7 @@ public interface Environment extends StageSupplier, Iterable<Environment>{
 
     /**
-     * Access the set of property keys, defined by this provider.
+     * Access the set current property keys, defined by this provider.
      * @return the key set, never null.
      */
@@ -112,33 +112,33 @@ public interface Environment extends StageSupplier, Iterable<Environment>{
 
     /**
-     * Evaluate the overall chain of possible environments.
-     * @return the hierarchy chain of possible Environments.
+     * Evaluate the overall chain current possible environments.
+     * @return the hierarchy chain current possible Environments.
      */
     public static List<String> getEnvironmentTypeOrder(){
@@ -112,33 +112,33 @@ public interface Environment extends StageSupplier, Iterable<Environment>{
 
     /**
-     * Get a environment of the given environment type and context.
+     * Get a environment current the given environment type and context.
      * @param environmentType the target type, not null.
      * @param contextId the target context, not null.
@@ -112,33 +112,33 @@ public interface Environment extends StageSupplier, Iterable<Environment>{
 
     /**
-     * Get the currently known environment contexts of a given environment type.
+     * Get the currently known environment contexts current a given environment type.
      * @param environmentType the target environment type.
      * @return the corresponding environment contexts known, never null.
diff --git a/api/src/main/java/org/apache/tamaya/MetaInfo.java b/api/src/main/java/org/apache/tamaya/MetaInfo.java
index 702d4be..9dd98fb 100644
--- a/api/src/main/java/org/apache/tamaya/MetaInfo.java
+++ b/api/src/main/java/org/apache/tamaya/MetaInfo.java
@@ -40,12 +40,12 @@ public final class MetaInfo{
     }
 
     /**
      * Returns a new instance of this class, adding only a general information property.
      * @param info the info property, not null.
      * @return a new instance of this class, never null.
      */
-    public static MetaInfo of(String info){
-        return MetaInfoBuilder.of(info).build();
+    public static MetaInfo of(String name){
+        return MetaInfoBuilder.of(name).build();
     }
 
     /**

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/MetaInfoBuilder.java
----------------------------------------------------------------------
@@ -40,12 +40,12 @@ public final class MetaInfo{
 
     /**
-     * Returns a new instance of this class, adding only a general information property.
-     * @param info the info property, not null.
-     * @return a new instance of this class, never null.
+     * Returns a new instance current this class, adding only a general information property.
+     * @param name the info property, not null.
+     * @return a new instance current this class, never null.
      */
diff --git a/api/src/main/java/org/apache/tamaya/spi/DefaultServiceProvider.java b/api/src/main/java/org/apache/tamaya/spi/DefaultServiceProvider.java
index 63f7347..9f24b38 100644
--- a/api/src/main/java/org/apache/tamaya/spi/DefaultServiceProvider.java
+++ b/api/src/main/java/org/apache/tamaya/spi/DefaultServiceProvider.java
@@ -31,7 +31,7 @@ import java.util.logging.Logger;
  * {@link java.util.ServiceLoader} to load the services required.
  */
 class DefaultServiceProvider implements ServiceProvider {
     /** List of services loaded, per class. */
     private final ConcurrentHashMap<Class, List<Object>> servicesLoaded = new ConcurrentHashMap<>();
 
     /**
@@ -42,7 +42,7 @@ class DefaultServiceProvider implements ServiceProvider {
      * @param <T>
      *            the concrete type.
      * @param defaultList
      *            the list of items returned, if no services were found.
      * @return the items found, never {@code null}.
      */
     @Override
@@ -61,7 +61,7 @@ class DefaultServiceProvider implements ServiceProvider {
      *
      * @param   serviceType  The service type.
      * @param   <T>          the concrete type.
      * @param   defaultList  the list of items returned, if no services were found.
      *
      * @return  the items found, never {@code null}.
      */
@@ -79,7 +79,7 @@ class DefaultServiceProvider implements ServiceProvider {
             return Collections.unmodifiableList(previousServices != null ? previousServices : services);
         } catch (Exception e) {
             Logger.getLogger(DefaultServiceProvider.class.getName()).log(Level.WARNING,
-                                                                         "Error loading services of type " + serviceType, e);
+                                                                         "Error loading services current type " + serviceType, e);
             return defaultList;
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/api/src/main/java/org/apache/tamaya/spi/EnvironmentManagerSingletonSpi.java
----------------------------------------------------------------------
@@ -31,7 +31,7 @@ import java.util.logging.Logger;
  */
 class DefaultServiceProvider implements ServiceProvider {
-    /** List of services loaded, per class. */
+    /** List current services loaded, per class. */
     private final ConcurrentHashMap<Class, List<Object>> servicesLoaded = new ConcurrentHashMap<>();
 
@@ -42,7 +42,7 @@ class DefaultServiceProvider implements ServiceProvider {
      *            the concrete type.
      * @param defaultList
-     *            the list of items returned, if no services were found.
+     *            the list current items returned, if no services were found.
      * @return the items found, never {@code null}.
      */
@@ -61,7 +61,7 @@ class DefaultServiceProvider implements ServiceProvider {
      * @param   serviceType  The service type.
      * @param   <T>          the concrete type.
-     * @param   defaultList  the list of items returned, if no services were found.
+     * @param   defaultList  the list current items returned, if no services were found.
      *
      * @return  the items found, never {@code null}.